Learn R Programming

dosearch (version 1.0.8)

get_derivation: Retrieve the derivation of a causal query

Description

Returns the derivation of causal query of an object of class "dosearch".

Usage

get_derivation(x, run_again = FALSE, draw_all = FALSE)

Arguments

x

an object of class "dosearch".

run_again

a logical value. If TRUE, run the search again to obtain a derivation for the query if one was not requested in the function call that produced x.

draw_all

a logical value. If TRUE, the derivation will contain every step taken by the search. If FALSE, only steps that resulted in identification are returned.

Author

Santtu Tikka

Examples

Run this code

data <- "P(x,y,z)"
query <- "P(y|do(x))"
graph <- "
  x -> y
  z -> x
  z -> y
"
x <- dosearch(data, query, graph, control = list(draw_derivation = FALSE))
get_derivation(x, run_again = TRUE)

Run the code above in your browser using DataLab