Learn R Programming

dosearch (version 1.0.8)

get_formula: Retrieve the identifying formula of a causal query

Description

Returns the identifying formula describing a causal query of an object of class "dosearch".

Usage

get_formula(x, run_again = FALSE)

Value

A character string representing the query in terms of the input data.

Arguments

x

an object of class "dosearch".

run_again

a logical value. If TRUE, run the search again to obtain a formula for the query if one was not requested in the function call that produced x.

Author

Santtu Tikka

Examples

Run this code

data <- "P(x,y,z)"
query <- "P(y|do(x))"
graph <- "
  x -> y
  z -> x
  z -> y
"
x <- dosearch(data, query, graph, control = list(formula = FALSE))
get_formula(x, run_again = TRUE)

Run the code above in your browser using DataLab