powered by
Returns the a logical value describing the identifiability of a causal query of an object of class "dosearch".
is_identifiable(x)
A logical value. If TRUE, the target distribution is identifiable from the available inputs.
TRUE
an object of class "dosearch".
Santtu Tikka
data <- "P(x,y,z)" query <- "P(y|do(x))" graph <- " x -> y z -> x z -> y " x <- dosearch(data, query, graph) is_identifiable(x) # TRUE
Run the code above in your browser using DataLab