a logical value. If TRUE, run the search again to obtain a derivation for the query if one was not requested in the function call that produced x.
draw_all
a logical value. If TRUE, the derivation will contain every step taken by the search. If FALSE, only steps that resulted in identification are returned.
data <- "P(x,y,z)"query <- "P(y|do(x))"graph <- "
x -> y
z -> x
z -> y
"x <- dosearch(data, query, graph, control = list(draw_derivation = FALSE))
get_derivation(x, run_again = TRUE)