powered by
Returns the identifying formula describing a causal query of an object of class "dosearch".
get_formula(x, run_again = FALSE)
A character string representing the query in terms of the input data.
an object of class "dosearch".
a logical value. If TRUE, run the search again to obtain a formula for the query if one was not requested in the function call that produced x.
TRUE
x
Santtu Tikka
data <- "P(x,y,z)" query <- "P(y|do(x))" graph <- " x -> y z -> x z -> y " x <- dosearch(data, query, graph, control = list(formula = FALSE)) get_formula(x, run_again = TRUE)
Run the code above in your browser using DataLab